Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(249)

Unified Diff: content/renderer/input/input_event_filter.h

Issue 2765583002: Teach main thread event queue about closures. (Closed)
Patch Set: Add comments Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/input/input_event_filter.h
diff --git a/content/renderer/input/input_event_filter.h b/content/renderer/input/input_event_filter.h
index 939e723d25f5a18d5e6cb649c3691cba254aac63..ee010129060b6c7d3fe278fc047d0d20e4b5ce20 100644
--- a/content/renderer/input/input_event_filter.h
+++ b/content/renderer/input/input_event_filter.h
@@ -63,6 +63,11 @@ class CONTENT_EXPORT InputEventFilter : public InputHandlerManagerClient,
void SetInputHandlerManager(InputHandlerManager*) override;
void RegisterRoutingID(int routing_id) override;
void UnregisterRoutingID(int routing_id) override;
+ void AssociateRenderFrameRoutingID(int render_frame_routing_id,
+ int render_view_routing_id) override;
tdresser 2017/03/30 17:46:16 RegisterAssociatedRenderFrameRoutingID?
dtapuska 2017/03/30 19:45:51 Done.
+ void QueueClosureForMainThreadEventQueue(
+ int routing_id,
+ const base::Closure& closure) override;
void DidOverscroll(int routing_id,
const ui::DidOverscrollParams& params) override;
void DidStopFlinging(int routing_id) override;
@@ -102,7 +107,8 @@ class CONTENT_EXPORT InputEventFilter : public InputHandlerManagerClient,
private:
~InputEventFilter() override;
- void ForwardToHandler(const IPC::Message& message,
+ void ForwardToHandler(int routing_id,
+ const IPC::Message& message,
base::TimeTicks received_time);
void DidForwardToHandlerAndOverscroll(
int routing_id,
@@ -129,13 +135,20 @@ class CONTENT_EXPORT InputEventFilter : public InputHandlerManagerClient,
// Protects access to routes_.
base::Lock routes_lock_;
// Indicates the routing_ids for which input events should be filtered.
std::set<int> routes_;
using RouteQueueMap =
std::unordered_map<int, scoped_refptr<MainThreadEventQueue>>;
+ // Maps RenderView routing ids to a MainThreadEventQueue.
RouteQueueMap route_queues_;
+ using AssociatedRoutes = std::unordered_map<int, int>;
+ // Maps RenderFrame routing ids to RenderView routing ids so that
+ // events sent down the two routing pipes can be handled synchronously.
+ AssociatedRoutes associated_routes_;
+
blink::scheduler::RendererScheduler* renderer_scheduler_;
};
@@ -129,13 +135,20 @@ class CONTENT_EXPORT InputEventFilter : public InputHandlerManagerClient,
// Protects access to routes_.
base::Lock routes_lock_;
- // Indicates the routing_ids for which input events should be filtered.
+ // Indicates the routing ids for RenderViews for which input events
+ // should be filtered.
std::set<int> routes_;
using RouteQueueMap =

Powered by Google App Engine
This is Rietveld 408576698